Title: [7234] trunk/drivers/input/touchscreen: The AD7889 is a new part but 100% software compatible with the AD7879
Revision
7234
Author
hennerich
Date
2009-08-24 22:49:17 -0400 (Mon, 24 Aug 2009)

Log Message

The AD7889 is a new part but 100% software compatible with the AD7879
Therefore add it to the id_table and help text.

Modified Paths

Diff

Modified: trunk/drivers/input/touchscreen/Kconfig (7233 => 7234)


--- trunk/drivers/input/touchscreen/Kconfig	2009-08-25 02:29:35 UTC (rev 7233)
+++ trunk/drivers/input/touchscreen/Kconfig	2009-08-25 02:49:17 UTC (rev 7234)
@@ -48,8 +48,8 @@
 	select TOUCHSCREEN_AD7879
 	help
 	  Say Y here if you have a touchscreen interface using the
-	  AD7879-1 controller, and your board-specific initialization
-	  code includes that in its table of I2C devices.
+	  AD7879-1/AD7889-1 controller, and your board-specific
+	  initialization code includes that in its table of I2C devices.
 
 	  If unsure, say N (but it's safe to say "Y").
 
@@ -62,7 +62,7 @@
 	select TOUCHSCREEN_AD7879
 	help
 	  Say Y here if you have a touchscreen interface using the
-	  AD7879 controller, and your board-specific initialization
+	  AD7879/AD7889 controller, and your board-specific initialization
 	  code includes that in its table of SPI devices.
 
 	  If unsure, say N (but it's safe to say "Y").

Modified: trunk/drivers/input/touchscreen/ad7879.c (7233 => 7234)


--- trunk/drivers/input/touchscreen/ad7879.c	2009-08-25 02:29:35 UTC (rev 7233)
+++ trunk/drivers/input/touchscreen/ad7879.c	2009-08-25 02:49:17 UTC (rev 7234)
@@ -1,7 +1,8 @@
 /*
- * Copyright (C) 2008 Michael Hennerich, Analog Devices Inc.
+ * Copyright (C) 2008-2009 Michael Hennerich, Analog Devices Inc.
  *
  * Description:	AD7879 based touchscreen, and GPIO driver (I2C/SPI Interface)
  *
  * Bugs:        Enter bugs at http://blackfin.uclinux.org/
  *
@@ -747,6 +748,7 @@
 
 static const struct i2c_device_id ad7879_id[] = {
 	{ "ad7879", 0 },
+	{ "ad7889", 0 },
 	{ }
 };
 MODULE_DEVICE_TABLE(i2c, ad7879_id);
@@ -1,7 +1,8 @@
  *
- * Description:	AD7879 based touchscreen, and GPIO driver (I2C/SPI Interface)
+ * Description:	AD7879/AD7889 based touchscreen, and GPIO driver
+ *		(I2C/SPI Interface)
  *
  * Bugs:        Enter bugs at http://blackfin.uclinux.org/
_______________________________________________
Linux-kernel-commits mailing list
[email protected]
https://blackfin.uclinux.org/mailman/listinfo/linux-kernel-commits

Reply via email to